from .biz import BizService
from .card import CardService
# import biz
# import card
NAME = "pyiikoapi"
__author__ = 'kebrick'
__version__ = '0.0.2'
__email__ = 'ruban.kebr@gmail.com'

